@@ -7,19 +7,22 @@
 
       INTEGER   IMAGE(*)
       REAL      WPX(*), WPY(*)
-      LOGICAL   LFCATR, LWDATR, LCLATR, LTNATR, LIMATR, LPTATR
-      LOGICAL   LFCMOD
+      LOGICAL   LWDATR, LCLATR, LTNATR, LIMATR, LPTATR
       CHARACTER COBJ*(*), COMM*(*)
 
       LOGICAL   LWAIT, LWAIT0, LWAIT1, LKEY, LDUMP, LALT,
-     +          LCOLOR, LSEP, LPRINT, LFGBG
+     +          LCOLOR, LSEP, LPRINT, LFGBG, LOPEN
       CHARACTER CMSG*80, CLRMAP*80, CBTMAP*80, CLPR*80, COUT*80, 
-     +          CTTL*80, CMAP*80
+     +          CTTL*80, CMAP*80, DSPATH*80
       LOGICAL   LWND
       CHARACTER CIMGFMT*8
+      REAL      RIMGCMP
+      CHARACTER CNOPN*26
 
       SAVE
 
+      DATA      CNOPN / 'WORKSTATION IS NOT OPENED.' /
+      DATA      LOPEN / .FALSE. /
 
 *     / OPEN ( AND ACTIVATE ) WORKSTATION /
 
@@ -42,8 +45,12 @@
         CALL SWCGET('TITLE  ', CTTL  )
 
         CALL SWCMLL
-        CALL SWQCMF(ICLRMP,CMAP)
-        CALL SWCSET('CLRMAP ',CMAP)
+        CALL SWQFNM('CLRMAP ', CLRMAP)
+        CALL GLCGET('DSPATH',  DSPATH)
+        IF (CLRMAP.EQ.(DSPATH(1:LENC(DSPATH))//'colormap.x11')) THEN
+          CALL SWQCMF(ICLRMP,CMAP)
+          CALL SWCSET('CLRMAP ',CMAP)
+        END IF
 
         CALL SWQFNM('CLRMAP ', CLRMAP)
         IF (CLRMAP.EQ.' ') THEN
@@ -117,11 +124,13 @@
         CALL SWLGET('LWND   ', LWND  )
 
         CALL SWCGET('CIMGFMT ', CIMGFMT)
+        CALL SWRGET('RIMGCMP ', RIMGCMP)
 
         CALL ZGDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
      +       LWAIT, LWAIT0, LWAIT1, LKEY, LDUMP, LWND, LFGBG,
-     +       CIMGFMT, CLRMAP, CBTMAP, COUT, CTTL)
+     +       CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT, CTTL)
       END IF
+      LOPEN = .TRUE.
 
       RETURN
 *-----------------------------------------------------------------------
@@ -138,6 +147,7 @@
       IF (IWS.EQ.4) CALL ZGDCLS
       CMSG='GRPH1 : TERMINATED.'
       CALL MSGDMP('M','SWDCLS',CMSG)
+      LOPEN = .FALSE.
 
       RETURN
 *-----------------------------------------------------------------------
@@ -147,6 +157,8 @@
 
 *     / OPEN PAGE ( OR SCREEN ) /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWPOPN', CNOPN)
       IF (IWS.EQ.1) CALL ZXPOPN
       IF (IWS.EQ.2) CALL Z1POPN
       IF (IWS.EQ.3) CALL ZTPOPN
@@ -158,6 +170,8 @@
 
 *     / CLOSE PAGE ( OR SCREEN ) /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWPCLS', CNOPN)
       NPAGE=NPAGE+1
       CMSG='GRPH1 : PAGE = ### COMPLETED.'
       CALL CHNGI(CMSG,'###',NPAGE,'(I3)')
@@ -176,6 +190,8 @@
 
 *     / OPEN OBJECT /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWOOPN', CNOPN)
       IF (IWS.EQ.1) CALL ZXOOPN(COBJ, COMM)
       IF (IWS.EQ.2) CALL Z1OOPN(COBJ, COMM)
       IF (IWS.EQ.3) CALL ZTOOPN(COBJ, COMM)
@@ -187,46 +203,23 @@
 
 *     / CLOSE OBJECT /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWOCLS', CNOPN)
       IF (IWS.EQ.1) CALL ZXOCLS(COBJ)
       IF (IWS.EQ.2) CALL Z1OCLS(COBJ)
       IF (IWS.EQ.3) CALL ZTOCLS(COBJ)
       IF (IWS.EQ.4) CALL ZGOCLS(COBJ)
 
       RETURN
-
-
-*-----------------------------------------------------------------------
-*     FULL COLOR (2000/12/10 TEST)
-*-----------------------------------------------------------------------
-      ENTRY SWQFCC(LFCATR)
-
-*     / INQUIRE FULL COLOR CAPABILITY /
-
-      IF (IWS.EQ.1) CALL ZXQFCC(LFCATR)
-      IF (IWS.EQ.2) LFCATR = .TRUE.
-      IF (IWS.EQ.3) LFCATR = .FALSE.
-      IF (IWS.EQ.4) LFCATR = .TRUE.
-
-      RETURN
-*-----------------------------------------------------------------------
-      ENTRY SWSFCM(LFCMOD)
-
-*     / SET FULL COLOR MODE /
-
-       IF (IWS.EQ.1) CALL ZXSFCM(LFCMOD)
-       IF (IWS.EQ.2) CALL Z1SFCM(LFCMOD)
-*      IF (IWS.EQ.3) CALL ZTSFCM(LFCMOD)
-       IF (IWS.EQ.4) CALL ZGSFCM(LFCMOD)
-
-      RETURN
 *-----------------------------------------------------------------------
 *     LINE
 *-----------------------------------------------------------------------
-
       ENTRY SWSWDI(IWDIDX)
 
 *     / SET LINE WIDTH INDEX /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWSWDI', CNOPN)
       IF (IWS.EQ.1) CALL ZXSWDI(IWDIDX)
       IF (IWS.EQ.2) CALL Z1SWDI(IWDIDX)
       IF (IWS.EQ.3) CALL ZTSWDI(IWDIDX)
@@ -238,29 +231,21 @@
 
 *     / SET LINE COLOR INDEX /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWSCLI', CNOPN)
       IF (IWS.EQ.1) CALL ZXSCLI(ICLIDX)
       IF (IWS.EQ.2) CALL Z1SCLI(ICLIDX)
       IF (IWS.EQ.3) CALL ZTSCLI(ICLIDX)
       IF (IWS.EQ.4) CALL ZGSCLI(ICLIDX)
 
       RETURN
-*-----------------------------------------------------------------------
-      ENTRY SWSLCL(ICOLOR)
-
-*     / SET LINE COLOR IN 24BIT RGB /
-
-      IF (IWS.EQ.1) CALL ZXSLCL(ICOLOR)
-      IF (IWS.EQ.2) CALL Z1SLCL(ICOLOR)
-      IF (IWS.EQ.4) CALL ZGSLCL(ICOLOR)
-
-      RETURN
-*-----------------------------------------------------------------------
-*     OPEN
 *-----------------------------------------------------------------------
       ENTRY SWGOPN
 
 *     / OPEN GRAPHIC SEGMENT /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWGOPN', CNOPN)
       IF (IWS.EQ.1) CALL ZXGOPN
       IF (IWS.EQ.2) CALL Z1GOPN
       IF (IWS.EQ.3) CALL ZTGOPN
@@ -272,6 +257,8 @@
 
 *     / PEN-UP MOVE /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWGMOV', CNOPN)
       IF (IWS.EQ.1) CALL ZXGMOV(WX,WY)
       IF (IWS.EQ.2) CALL Z1GMOV(WX,WY)
       IF (IWS.EQ.3) CALL ZTGMOV(WX,WY)
@@ -283,19 +270,21 @@
 
 *     / PEN-DOWN MOVE /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWGPLT', CNOPN)
       IF (IWS.EQ.1) CALL ZXGPLT(WX,WY)
       IF (IWS.EQ.2) CALL Z1GPLT(WX,WY)
       IF (IWS.EQ.3) CALL ZTGPLT(WX,WY)
       IF (IWS.EQ.4) CALL ZGGPLT(WX,WY)
 
       RETURN
-*-----------------------------------------------------------------------
-*     CLOSE
 *-----------------------------------------------------------------------
       ENTRY SWGCLS
 
 *     / CLOSE GRAPHIC SEGMENT /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWGCLS', CNOPN)
       IF (IWS.EQ.1) CALL ZXGCLS
       IF (IWS.EQ.2) CALL Z1GCLS
       IF (IWS.EQ.3) CALL ZTGCLS
@@ -304,22 +293,13 @@
       RETURN
 *-----------------------------------------------------------------------
 *     TONE
-*-----------------------------------------------------------------------
-      ENTRY SWSTCL(ICOLOR)
-
-*     / SET TONE COLOR IN 24BIT RGB /
-
-      IF (IWS.EQ.1) CALL ZXSTCL(ICOLOR)
-      IF (IWS.EQ.2) CALL Z1STCL(ICOLOR)
-*      IF (IWS.EQ.3) CALL ZTSTCL(ICOLOR)
-      IF (IWS.EQ.4) CALL ZGSTCL(ICOLOR)
-
-      RETURN
 *-----------------------------------------------------------------------
       ENTRY SWGTON(NP,WPX,WPY,ITPAT)
 
 *     / HARD FILL /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWGTON', CNOPN)
       IF (IWS.EQ.1) CALL ZXGTON(NP,WPX,WPY,ITPAT)
       IF (IWS.EQ.2) CALL Z1GTON(NP,WPX,WPY,ITPAT)
       IF (IWS.EQ.3) CALL ZTGTON(NP,WPX,WPY,ITPAT)
@@ -334,11 +314,11 @@
 
 *     / OPEN IMAGE /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWIOPN', CNOPN)
       IF (IWS.EQ.1) CALL ZXIOPN(IWX, IWY, IMW, IMH)
       IF (IWS.EQ.2) THEN
-*        WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4
-*         Makes Segmentation Fault
-*        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
+        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
         CALL Z1IOPN(IWX, IWY, IMW, IMH)
       ENDIF
       IF (IWS.EQ.3) CALL ZTIOPN(IWX, IWY, IMW, IMH)
@@ -350,27 +330,21 @@
 
 *     / IMAGE DATA /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWIDAT', CNOPN)
       IF (IWS.EQ.1) CALL ZXIDAT(IMAGE, NLEN)
       IF (IWS.EQ.2) CALL Z1IDAT(IMAGE, NLEN)
       IF (IWS.EQ.3) CALL ZTIDAT(IMAGE, NLEN)
       IF (IWS.EQ.4) CALL ZGIDAT(IMAGE, NLEN)
 
-      RETURN
-*-----------------------------------------------------------------------
-      ENTRY SWICLR(IMAGE, NLEN)
-
-*     / IMAGE DATA (FULL COLOR) /
-      IF (IWS.EQ.1) CALL ZXICLR(IMAGE, NLEN)
-      IF (IWS.EQ.2) CALL Z1ICLR(IMAGE, NLEN)
-*      IF (IWS.EQ.3) CALL ZTICLR(IMAGE, NLEN)
-      IF (IWS.EQ.4) CALL ZGICLR(IMAGE, NLEN)
-
       RETURN
 *-----------------------------------------------------------------------
       ENTRY SWICLS
 
 *     / IMAGE CLOSE /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWICLS', CNOPN)
       IF (IWS.EQ.1) CALL ZXICLS
       IF (IWS.EQ.2) CALL Z1ICLS
       IF (IWS.EQ.3) CALL ZTICLS
@@ -384,6 +358,8 @@
 
 *     / INQUIRE POSITION OF POINTER /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWQPNT', CNOPN)
       IF (IWS.EQ.1) CALL ZXQPNT(WX,WY,MB)
       IF (IWS.EQ.2) CALL Z1QPNT(WX,WY,MB)
       IF (IWS.EQ.3) CALL ZTQPNT(WX,WY,MB)
@@ -397,6 +373,8 @@
 
 *     / REAL TO INT /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWFINT', CNOPN)
       IF (IWS.EQ.1) CALL ZXFINT(WX, WY, IWX, IWY)
       IF (IWS.EQ.2) CALL Z1FINT(WX, WY, IWX, IWY)
       IF (IWS.EQ.3) CALL ZTFINT(WX, WY, IWX, IWY)
@@ -408,6 +386,8 @@
 
 *     / INT TO REAL /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWIINT', CNOPN)
       IF (IWS.EQ.1) CALL ZXIINT(IWX, IWY, WX, WY)
       IF (IWS.EQ.2) CALL Z1IINT(IWX, IWY, WX, WY)
       IF (IWS.EQ.3) CALL ZTIINT(IWX, IWY, WX, WY)
@@ -432,6 +412,8 @@
 
 *     / INQUIRE LINE COLOR CAPABILITY /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWQCLC', CNOPN)
       IF (IWS.EQ.1) CALL ZXQCLC(LCLATR)
       IF (IWS.EQ.2) CALL Z1QCLC(LCLATR)
       IF (IWS.EQ.3) CALL ZTQCLC(LCLATR)
@@ -476,6 +458,8 @@
 
 *     / INQUIRE WORKSTATION RECTANGLE /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWQRCT', CNOPN)
       IF (IWS.EQ.1) CALL ZXQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
       IF (IWS.EQ.2) CALL Z1QRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
       IF (IWS.EQ.3) CALL ZTQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
@@ -487,6 +471,8 @@
 
 *     / SET FRAME ROTATION FLAG /
 
+      IF (.NOT. LOPEN)
+     +   CALL MSGDMP('E', 'SWSROT', CNOPN)
       IF (IWS.EQ.1) CALL ZXSROT(IWTROT)
       IF (IWS.EQ.2) CALL Z1SROT(IWTROT)
       IF (IWS.EQ.3) CALL ZTSROT(IWTROT)
