@@ -9,9 +9,8 @@
  *    93/02/01  A. Numaguti: conforming PostScript (PS-Adobe-2.0)
  *    94/01/28  S. Sakai: dcl-5.x.3
  *    94/03/15  M. Shiotani
- *     2010/08/21 N.Otobe (Full Color)
  *
- *    Copyright (C) 2000-2010 GFD Dennou Club. All rights reserved.
+ *    Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
  *
  */
 
@@ -50,8 +49,6 @@ static int page = 0;
 static float wsxwd, wsywd, wsxmnz, wsxmxz, wsymnz, wsymxz; /* window size */
 static float factz, scale;
 
-static int lfcmod = FALSE;
-
 static FILE *outf;                       /* PS file */
 static int color, separate, print;       /* initialized by z1dopn */
 static char psfile[80], command[80], fname[80], xtitle[80];
@@ -240,12 +237,10 @@ void z1gopn_(void)
 	fprintf (outf, "%4.1f W\n", xlwdth[iwdidz-1]);
 	iwdidy = iwdidz;
     }
-    if (lfcmod == FALSE){
     if (color && iclidz != iclidy) {
 	fprintf (outf, "%4i RGB\n", rgb[iclidz]);
 	iclidy = iclidz;
     }
-    }
     fputs ("N\n", outf);
 }
 
@@ -566,75 +561,3 @@ static void z1fcls(void)
     fputs ("%%EOF\n", outf);
     fclose (outf);
 }
-
-
-
-void z1sfcm_(DCL_INT *lfc)
-{
-  lfcmod = *lfc;
-}
-void z1slcl_(DCL_INT *icolor)
-{
-  float r, g, b ;
-  int ri,gi,bi;
- 
-  ri = ((*icolor >> 16) & 255);
-  gi = ((*icolor >> 8)  & 255);
-  bi = ((*icolor >> 0)  & 255);
-
-  r = (float) ri /256;
-  g = (float) gi /256;
-  b = (float) bi /256;
-
-//    if (color && iclidz != iclidy) {
-	fprintf (outf, "%.3f %.3f %.3f setrgbcolor\n", r,g,b);
-//	iclidy = iclidz;
-//    }
-}
-void z1stcl_(DCL_INT *icolor)
-{
-  float r, g, b ;
-  int ri,gi,bi;
- 
-  ri = ((*icolor >> 16) & 255);
-  gi = ((*icolor >> 8)  & 255);
-  bi = ((*icolor >> 0)  & 255);
-
-  r = (float) ri /256;
-  g = (float) gi /256;
-  b = (float) bi /256;
-
-//    if (color && iclidz != iclidy) {
-	fprintf (outf, "%.3f %.3f %.3f setrgbcolor\n", r,g,b);
-//	iclidy = iclidz;
-//    }  printf("z1stcl : Not Yet\n"); 
-}
-void z1iclr_(DCL_INT *image,DCL_INT *nlen)
-{
-
-  float r, g, b ;
-  int ri,gi,bi;
-  int i;
-
-  for (i = 0; i < *nlen; i++) {
-	ipxcl++;
-
-    ri = ((image[i] >> 16) & 255);
-    gi = ((image[i] >> 8)  & 255);
-    bi = ((image[i] >> 0)  & 255);
-
-    r = (float) ri /256;
-    g = (float) gi /256;
-    b = (float) bi /256;
-
-	fprintf (outf, "%2.2x%2.2x%2.2x", ri, gi, bi);
-
-	if ((ipxcl % 10) == 0)
-	    fputs("\n", outf);
-    }
-
-}
-
-
-
-
