@@ -8,7 +8,13 @@
       PARAMETER (MAXPXL=4000)
 
       INTEGER   IMAGE(MAXPXL)
-      LOGICAL   LIMC
+      LOGICAL   LMISS,LIMC
+
+      COMMON    /UEBLK1/ TL1,TL2,IPT,NT,LASCND
+      PARAMETER (MAXNT=100)
+      LOGICAL   LASCND
+      INTEGER   IPT(MAXNT)
+      REAL      TL1(MAXNT),TL2(MAXNT)
 
       EXTERNAL  IUETON, IUWGX, IUWGY
 
@@ -24,6 +30,8 @@
 
       CALL GLRGET('RUNDEF  ',RUNDEF)
       CALL GLIGET('IUNDEF  ',IUNDEF)
+      CALL GLLGET('LMISS   ',LMISS )
+      CALL GLRGET('RMISS   ',RMISS )
 
 *     / SET GRID ATTRIBUTE IF IT HAS NOT BEEN SET YET /
 
@@ -80,7 +88,7 @@
             CALL STITRF(VX, VY, UX, UY)
           END IF
 
-          IF (UX .EQ. RUNDEF) THEN
+          IF (UX.EQ.RUNDEF) THEN
             IMAGE(I) = 0
           ELSE
             IX = IUWGX(UX)
@@ -89,7 +97,15 @@
               IMAGE(I) = 0
             ELSE
               ZZ = Z(IX, IY)
-              IMAGE(I) = IUETON(ZZ)/1000
+              IF (LMISS .AND. ZZ.EQ.RMISS) THEN
+                IMAGE(I) = 0
+              ELSE
+                IF (TL1(1) .LE. ZZ .AND. ZZ .LE. TL2(NT)) THEN
+                  IMAGE(I) = IUETON(ZZ)/1000
+                ELSE
+                  IMAGE(I) = 0
+                END IF
+              END IF
             END IF
           END IF
 
