@@ -8,9 +8,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-void osexec_(cmd, Lcmd)
-    char *cmd;
-    int Lcmd;
+void osexec_(char *cmd, int Lcmd)
 {
     int nc;
     char cmdx[80];
