@@ -8,9 +8,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-void osgenv_(cename, ceval, Lename, Leval)
-    char *cename, *ceval;
-    int  Lename, Leval;
+void osgenv_(char *cename, char *ceval, int Lename, int Leval)
 {
     int nc;
     char cpx[80], *buf;
